@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -22,7 +24,6 @@ using System.Collections.Generic;
 using System.Reflection;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
 
 namespace gbrainy.Clients.Classical
 {
@@ -34,9 +35,8 @@ namespace gbrainy.Clients.Classical
 
 		public static readonly char GAME_SEPARATOR = ',';
 
-		public CommandLine (ITranslations translations, string [] args)
+		public CommandLine (string [] args)
 		{
-			Translations = translations;
 			this.args = args;
 			RandomOrder = true;
 			play_list = new int [0];
@@ -52,8 +52,6 @@ namespace gbrainy.Clients.Classical
 
 		public bool RandomOrder { get; set; }
 
-		ITranslations Translations {get; set;}
-
 		public void Parse ()
 		{
 			cont_execution = true;
@@ -95,7 +93,7 @@ namespace gbrainy.Clients.Classical
 					cont_execution = false;
 					break;
 				default:
-					Console.WriteLine (Catalog.GetString ("Unknown command line parameter {0}"), args [idx]);
+					Console.WriteLine ("Unknown parameter {0}", args [idx]);
 					break;
 				}
 			}
@@ -103,15 +101,18 @@ namespace gbrainy.Clients.Classical
 
 		public static void Version ()
 		{
-			Console.WriteLine ("gbrainy " + Defines.VERSION);
+			Console.WriteLine ("gbrainy " + Defines.VERSION + " " +
+				// Translators: {0} is a date
+				String.Format (Catalog.GetString ("(built on {0})"), Defines.BUILD_TIME));
 		}
 
-		void GameList ()
+		static void GameList ()
 		{
-			GameLocator [] games;
+			GameManager.GameLocator [] games;
 			GameManager gm = new GameManager ();
 
 			GtkClient.GameManagerPreload (gm);
+			gm.GameType = GameSession.Types.AllGames;
 			games = gm.AvailableGames;
 
 			Console.WriteLine (Catalog.GetString ("List of available games"));
@@ -122,7 +123,6 @@ namespace gbrainy.Clients.Classical
 					continue;
 
 				Game game = (Game) Activator.CreateInstance (games[i].TypeOf, true);
-				game.Translations = Translations;
 				game.Variant = games[i].Variant;
 				Console.WriteLine (" {0}", game.Name);
 			}
@@ -130,30 +130,43 @@ namespace gbrainy.Clients.Classical
 
 		void BuildPlayList (string [] names)
 		{
-			List <int> list = new List <int> ();
-			GameLocator [] games;
+			Dictionary <string, int> dictionary;
+			GameManager.GameLocator [] games;
 			GameManager gm = new GameManager ();
 			GtkClient.GameManagerPreload (gm);
 			games = gm.AvailableGames;
 
+			// Create a hash to map from game name to locator
+			dictionary = new Dictionary <string, int> (games.Length);
 			for (int i = 0; i < games.Length; i++)
 			{
+				if (games[i].IsGame == false)
+					continue;
+
 				Game game = (Game) Activator.CreateInstance (games[i].TypeOf, true);
-				game.Translations = Translations;
 				game.Variant = games[i].Variant;
 
 				try
 				{
-					for (int n = 0; n < names.Length; n++)
-					{
-						if (String.Compare (game.Name, names [n], StringComparison.OrdinalIgnoreCase) == 0)
-							list.Add (i);
-					}
-
+					dictionary.Add (game.Name.ToLower (), i);
 				}
 				catch (Exception e)
 				{
-					Console.WriteLine ("CommandLine.BuildPlayList. Error adding {0} {1}", game.Name, e.Message);
+					Console.WriteLine ("gbrainy. Error adding {0} {1}", game.Name, e.Message);
+				}
+			}
+
+			List <int> list = new List <int> (names.Length);
+
+			for (int i = 0; i < names.Length; i++)
+			{
+				try
+				{
+					list.Add (dictionary [names [i].ToLower ()]);
+				}
+				catch (KeyNotFoundException)
+				{
+					Console.WriteLine ("gbrainy. Game [{0}] not found", names [i]);
 				}
 			}
 
