@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -21,7 +23,6 @@ using Mono.Unix;
 using System.Collections.Generic;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
 using gbrainy.Clients.Classical.Widgets;
 
 namespace gbrainy.Clients.Classical.Dialogs
@@ -30,11 +31,11 @@ namespace gbrainy.Clients.Classical.Dialogs
 	{
 		// This is static to allow to preserve the selection in different instances
 		static ListStore games_store;
-		[Builder.Object] Gtk.TreeView treeview;
-		[Builder.Object] Box preview_vbox;
+		[GtkBeans.Builder.Object] Gtk.TreeView treeview;
+		[GtkBeans.Builder.Object] Box preview_vbox;
 		GameDrawingArea drawing_area;
-		GameSession session;
-		GameLocator [] games;
+		GameManager manager;
+		GameManager.GameLocator [] games;
 		bool selection_done;
 
 		const int COL_NAME = 0;
@@ -43,63 +44,20 @@ namespace gbrainy.Clients.Classical.Dialogs
 		const int COL_OBJECT = 3;
 		const int COL_INDEX = 4;
 
-		public CustomGameDialog (ITranslations translations, GameSession session) : base (translations, "CustomGameDialog.ui", "customgame")
+		public CustomGameDialog (GameManager manager) : base ("CustomGameDialog.ui", "customgame")
 		{
 			Game game;
 
 			selection_done = false;
-			this.session = session;
-			games = session.GameManager.AvailableGames;
+			this.manager = manager;
+			games = manager.AvailableGames;
 
 			drawing_area = new GameDrawingArea ();
 			drawing_area.UseSolutionArea = false;
-                        drawing_area.SetSizeRequest (preview_vbox.WidthRequest, preview_vbox.HeightRequest);
 			preview_vbox.Add (drawing_area);
 			drawing_area.Visible = true;
 			treeview.HeadersClickable = true;
 
-			CreateColumnName ();
-			CreateColumnType ();
-			CreateColumnSelected ();
-			LoadGames ();
-
-			treeview.Model = games_store;
-			game = (Game) Activator.CreateInstance (games [0].TypeOf, true);
-			game.Translations = Translations;
-			game.Variant = 0;
-			game.Begin ();
-			drawing_area.Drawable = game;
-			drawing_area.Question = game.Question;
-			treeview.ColumnsAutosize ();
-		}
-
-		void LoadGames ()
-		{
-			if (games_store != null)
-				return;
-
-			games_store = new ListStore (typeof(string), typeof (string), typeof(bool), typeof (Game), typeof (int));
-			games_store.SetSortFunc (0, new Gtk.TreeIterCompareFunc (GameSort));
-			games_store.SetSortColumnId (COL_TYPE, SortType.Ascending);
-				 
-			// Data
-			string type;
-			Game game;
-			for (int i = 0; i < games.Length; i++)
-			{
-				if (games [i].IsGame == false)
-					continue;
-
-				game = (Game) Activator.CreateInstance (games [i].TypeOf, true);
-				game.Translations = Translations;
-				game.Variant = games [i].Variant;
-				type = GameTypesDescription.GetLocalized (Translations, game.Type);
-				games_store.AppendValues (game.Name, type, true, game, i);
-			}
-		}
-
-		void CreateColumnName ()
-		{
 			// Column: Game Name
 			TreeViewColumn name_column = new TreeViewColumn (Catalog.GetString("Game Name"), 
 				new CellRendererText(), "text", 0);
@@ -122,10 +80,6 @@ namespace gbrainy.Clients.Classical.Dialogs
 
 			treeview.AppendColumn (name_column);
 
-		}
-
-		void CreateColumnType ()
-		{
 			// Column: Type
 			TreeViewColumn type_column = new TreeViewColumn (Catalog.GetString("Type"), 
 				new CellRendererText(), "text", 1);
@@ -146,11 +100,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 				column.SortOrder = order;
 				games_store.SetSortColumnId (COL_TYPE, order);
 			};
-		}
 
-
-		void CreateColumnSelected ()
-		{
 			// Column: Selected
 			CellRendererToggle toggle_cell = new CellRendererToggle();
 			TreeViewColumn toggle_column = new TreeViewColumn(Catalog.GetString("Selected"),
@@ -160,6 +110,34 @@ namespace gbrainy.Clients.Classical.Dialogs
 			toggle_column.Expand = false;
 			treeview.CursorChanged += OnCursorChanged;
 			treeview.AppendColumn (toggle_column);
+
+			if (games_store == null) {
+				games_store = new ListStore (typeof(string), typeof (string), typeof(bool), typeof (Game), typeof (int));
+
+				games_store.SetSortFunc (0, new Gtk.TreeIterCompareFunc (GameSort));
+				games_store.SetSortColumnId (COL_TYPE, SortType.Ascending);
+					 
+				// Data
+				string type;
+				for (int i = 0; i < games.Length; i++)
+				{
+					if (games [i].IsGame == false)
+						continue;
+
+					game = (Game) Activator.CreateInstance (games [i].TypeOf, true);
+					game.Variant = games [i].Variant;
+					type = GameTypesDescription.GetLocalized (game.Type);
+					games_store.AppendValues (game.Name, type, true, game, i);
+				}
+			}
+
+			treeview.Model = games_store;
+			game = (Game) Activator.CreateInstance (games [0].TypeOf, true);
+			game.Variant = 0;
+			game.Begin ();
+			drawing_area.Drawable = game;
+			drawing_area.Question = game.Question;
+			treeview.ColumnsAutosize ();
 		}
 
 		public bool SelectionDone {
@@ -174,7 +152,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			games_store = null;
 		}
 
-		int GameSort (Gtk.ITreeModel model, Gtk.TreeIter a, Gtk.TreeIter b)
+		int GameSort (Gtk.TreeModel model, Gtk.TreeIter a, Gtk.TreeIter b)
 		{
 			string name_a, name_b;
 			int sort_column_id;
@@ -223,7 +201,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 
 		void OnSelectAll (object sender, EventArgs args)
 		{
-			games_store.Foreach (delegate (ITreeModel model, TreePath path, TreeIter iter)  {
+			games_store.Foreach (delegate (TreeModel model, TreePath path, TreeIter iter)  {
 				games_store.SetValue (iter, COL_ENABLED, true);
 				return false;
 			});
@@ -231,7 +209,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 
 		void OnUnSelectAll (object sender, EventArgs args)
 		{
-			games_store.Foreach (delegate (ITreeModel model, TreePath path, TreeIter iter)  {
+			games_store.Foreach (delegate (TreeModel model, TreePath path, TreeIter iter)  {
 				games_store.SetValue (iter, COL_ENABLED, false);
 				return false;
 			});
@@ -243,7 +221,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 
 			play_list = new List <int> ();
 
-			games_store.Foreach (delegate (ITreeModel model, TreePath path, TreeIter iter)  {
+			games_store.Foreach (delegate (TreeModel model, TreePath path, TreeIter iter)  {
 				bool enabled = (bool) games_store.GetValue (iter, COL_ENABLED);
 
 				if (enabled == true) {
@@ -255,7 +233,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			});
 
 			if (selection_done == true)
-				session.PlayList.PlayList = play_list.ToArray ();
+				manager.PlayList = play_list.ToArray ();
 		}
 	}
 }
