@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -21,23 +23,22 @@ using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Views;
-using gbrainy.Core.Services;
 
 namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class PlayerHistoryDialog : BuilderDialog
 	{
-		[Builder.Object] Box history_preview;
-		[Builder.Object] Label label_playerhistory;
-		[Builder.Object] Gtk.CheckButton checkbutton_total;
-		[Builder.Object] Gtk.CheckButton checkbutton_memory;
-		[Builder.Object] Gtk.CheckButton checkbutton_logic;
-		[Builder.Object] Gtk.CheckButton checkbutton_calculation;
-		[Builder.Object] Gtk.CheckButton checkbutton_verbal;
+		[GtkBeans.Builder.Object] Box history_preview;
+		[GtkBeans.Builder.Object] Label label_playerhistory;
+		[GtkBeans.Builder.Object] Gtk.CheckButton checkbutton_total;
+		[GtkBeans.Builder.Object] Gtk.CheckButton checkbutton_memory;
+		[GtkBeans.Builder.Object] Gtk.CheckButton checkbutton_logic;
+		[GtkBeans.Builder.Object] Gtk.CheckButton checkbutton_calculation;
+		[GtkBeans.Builder.Object] Gtk.CheckButton checkbutton_verbal;
 
 		CairoPreview drawing_area;
 
-		public PlayerHistoryDialog (ITranslations translations, PlayerHistory history) : base (translations, "PlayerHistoryDialog.ui", "playerhistory")
+		public PlayerHistoryDialog (PlayerHistory history) : base ("PlayerHistoryDialog.ui", "playerhistory")
 		{
 			string intro, built;
 
@@ -58,16 +59,15 @@ namespace gbrainy.Clients.Classical.Dialogs
 			// Translators: "The graph below" +  "It is built using" sentences
 			label_playerhistory.Text = String.Format (Catalog.GetString ("{0} {1}"), intro, built);
 
-			drawing_area = new CairoPreview (translations, history);
-            drawing_area.SetSizeRequest (history_preview.WidthRequest, history_preview.HeightRequest);
+			drawing_area = new CairoPreview (history);
 			history_preview.Add (drawing_area);
 			drawing_area.Visible = true;
 
 	 		checkbutton_total.Label = Catalog.GetString ("Total");
-	 		checkbutton_logic.Label = GameTypesDescription.GetLocalized (translations, GameTypes.LogicPuzzle);
-	 		checkbutton_calculation.Label = GameTypesDescription.GetLocalized (translations, GameTypes.Calculation);
-	 		checkbutton_memory.Label = GameTypesDescription.GetLocalized (translations, GameTypes.Memory);
-	 		checkbutton_verbal.Label = GameTypesDescription.GetLocalized (translations, GameTypes.VerbalAnalogy);
+	 		checkbutton_logic.Label = GameTypesDescription.GetLocalized (GameTypes.LogicPuzzle);
+	 		checkbutton_calculation.Label = GameTypesDescription.GetLocalized (GameTypes.Calculation);
+	 		checkbutton_memory.Label = GameTypesDescription.GetLocalized (GameTypes.Memory);
+	 		checkbutton_verbal.Label = GameTypesDescription.GetLocalized (GameTypes.VerbalAnalogy);
 
 	 		checkbutton_total.Active = checkbutton_memory.Active = checkbutton_logic.Active = checkbutton_calculation.Active = checkbutton_verbal.Active = true;
 		}
@@ -106,16 +106,16 @@ namespace gbrainy.Clients.Classical.Dialogs
 		{
 			PlayerHistoryView view;
 
-			public CairoPreview (ITranslations translations, PlayerHistory history)
+			public CairoPreview (PlayerHistory history)
 			{
-				view = new PlayerHistoryView (translations, history);
+				view = new PlayerHistoryView (history);
 			}
 
 			public PlayerHistoryView View {
 				get { return view; }
 			}
 
-			protected override bool OnDrawn (Cairo.Context cc)
+			protected override bool OnExposeEvent (Gdk.EventExpose args)
 			{
 				if(!IsRealized)
 					return false;
@@ -123,10 +123,9 @@ namespace gbrainy.Clients.Classical.Dialogs
 				int w, h, nw, nh;
 				double x = 0, y = 0;
 
-				CairoContextEx cr = new CairoContextEx (cc.Handle);
-				cr.PangoFontDescription = PangoContext.FontDescription;
-                w = Window.Width;
-                h = Window.Height;
+				Cairo.Context cc = Gdk.CairoHelper.Create (args.Window);
+				CairoContextEx cr = new CairoContextEx (cc.Handle, this);
+				args.Window.GetSize (out w, out h);
 
 				nh = nw = Math.Min (w, h);
 
@@ -143,8 +142,9 @@ namespace gbrainy.Clients.Classical.Dialogs
 
 				view.Draw (cr, nw, nh, Direction == Gtk.TextDirection.Rtl);
 
+				((IDisposable)cc).Dispose();
 				((IDisposable)cr).Dispose();
-	   			return true;
+	   			return base.OnExposeEvent(args);
 			}
 		}
 	}
