@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -48,7 +50,7 @@ namespace gbrainy.Core.Main
 
 		public override string Question {
 			get {
-				return Translations.GetString ("Memorize the objects below in the given time");
+				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Memorize the objects below in the given time");
 			}
 		}
 
@@ -64,11 +66,6 @@ namespace gbrainy.Core.Main
 			}
 		}
 
-		// Shading does not work well when we have images
-		protected virtual bool SupportsShading {
-			get { return true; }
-		}
-
 		protected override void Initialize ()
 		{
 			if (Preferences.Get <bool> (Preferences.MemQuestionWarnKey) == false || 
@@ -77,7 +74,7 @@ namespace gbrainy.Core.Main
 				return;
 			}
 
-			downview = new CountDownView (Translations, OnCountDownFinish);
+			downview = new CountDownView (OnCountDownFinish);
 			downview.SynchronizingObject = SynchronizingObject;
 			downview.DrawRequest += OnCountDownRedraw;
 			downview.Start ();
@@ -119,9 +116,6 @@ namespace gbrainy.Core.Main
 
 		public void StartTimer ()
 		{
-			if (IsPreviewMode == true)
-				return;
-
 			timer.Enabled = true;
 			draw_timer = true;
 		}
@@ -164,20 +158,10 @@ namespace gbrainy.Core.Main
 				FinishCountDown ();
 			else 
 				timer.Enabled = false;
-
-            if (gradient != null) {
-                gradient.Dispose ();
-                gradient = null;
-            }
 		}		
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
-		{
-			if (IsPreviewMode) {
-				DrawPreview (gr, area_width, area_height, rtl);
-				return;
-			}
-
+		{			
 			if (downview != null) {
 				downview.Draw (gr, area_width, area_height, rtl);
 				return;
@@ -185,17 +169,17 @@ namespace gbrainy.Core.Main
 			
 			InitDraw (gr, area_width, area_height, rtl);
 
-			if (SupportsShading && shade) {
+			if (shade) {
 				if (alpha > 0)
 					alpha -= (1 / (double) shading_time);
 
-				gr.SetSourceColor (new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha));
+				gr.Color = new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha);
 				DrawObjectToMemorize (gr, area_width, area_height, rtl);
 				return;
 			}
 		
 			alpha = 1;
-			gr.SetSourceColor (new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha));
+			gr.Color = new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha);
 			if (request_answer && Answer.Draw == false) {
 				DrawPossibleAnswers (gr, area_width, area_height, rtl);
 			} else {
@@ -206,7 +190,7 @@ namespace gbrainy.Core.Main
 		public override void DrawPreview (CairoContextEx gr, int width, int height, bool rtl)
 		{
 			gr.Scale (width, height);
-			gr.SetSourceColor (new Cairo.Color (0, 0, 0));
+			gr.Color = new Cairo.Color (0, 0, 0);
 			gr.LineWidth = LineWidth;
 			DrawObjectToMemorize (gr, width, height, rtl);
 		}
@@ -233,11 +217,11 @@ namespace gbrainy.Core.Main
 			double width = 0.04, height = 0.6;
 			const double w = 0.003, h = 0.003;
 
-			gr.DrawTextCentered (x + (width / 2), y + height + 0.05, Translations.GetString ("Time left"));
+			gr.DrawTextCentered (x + (width / 2), y + height + 0.05, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Time left"));
 			gr.Stroke ();
 
 			gr.Save ();
-			gr.SetSourceColor (new Color (0, 0, 0));
+			gr.Color = new Color (0, 0, 0);	
 			gr.MoveTo (x, y);
 			gr.LineTo (x, y + height);
 			gr.LineTo (x + width, y + height);
@@ -258,7 +242,7 @@ namespace gbrainy.Core.Main
 				gradient.AddColorStop (1, new Color (0.2, 0, 0, 1));
 			}
 
-			gr.SetSource (gradient);
+			gr.Source = gradient;			
 			gr.MoveTo (x, y);
 			gr.LineTo (x, y + height);
 			gr.LineTo (x + width, y + height);
