@@ -12,13 +12,16 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
 using System.Collections.Generic;
 
 using gbrainy.Core.Libraries;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Core.Main.Verbal
 {
@@ -71,7 +74,7 @@ namespace gbrainy.Core.Main.Verbal
 				if (i + 1 < items.Length) {
 					// Translators: this the separator used when concatenating multiple possible answers for verbal analogies
 					// For example: "Possible correct answers are: sleep, rest."
-					str += Translations.GetString (", ");
+					str += ServiceLocator.Instance.GetService <ITranslations> ().GetString (", ");
 				}
 			}
 			Answer.CorrectShow = str;
@@ -113,7 +116,7 @@ namespace gbrainy.Core.Main.Verbal
 					if (GetText.StringExists (analogy.answers [indices[i]]) == false)
 						localized = false;
 
-					answers [i] = Translations.GetString (analogy.answers [indices[i]]);
+					answers [i] = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.answers [indices[i]]);
 					if (indices[i] == analogy.right)
 						new_right = i;
 				}
@@ -127,13 +130,13 @@ namespace gbrainy.Core.Main.Verbal
 				localized = false;
 
 			if (localized == true) {
-				analogy.question = Translations.GetString (analogy.question);
+				analogy.question = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.question);
 
 				if (String.IsNullOrEmpty (analogy.tip) == false)
-					analogy.tip = Translations.GetString (analogy.tip);
+					analogy.tip = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.tip);
 
 				if (String.IsNullOrEmpty (analogy.rationale) == false)
-					analogy.rationale = Translations.GetString (analogy.rationale);
+					analogy.rationale = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.rationale);
 			} else {
 
 				// Get analogy again
