@@ -12,13 +12,20 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
+using System.IO;
 using System.Collections.Generic;
 
+using Cairo;
+
+using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Core.Main.Verbal
 {
@@ -29,11 +36,11 @@ namespace gbrainy.Core.Main.Verbal
 		public AnalogiesMultipleOptions ()
 		{
 			if (analogies == null)
-				analogies = AnalogiesFactory.Get (Analogy.Type.MultipleOptions);
+				analogies = AnalogiesFactory. Get (Analogy.Type.MultipleOptions);
 		}
 
 		public override string Name {
-			get { return String.Format (Translations.GetString ("Multiple options #{0}"), Variant);}
+			get { return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Multiple options #{0}"), Variant);}
 		}
 
 		public override string Question {
@@ -46,7 +53,7 @@ namespace gbrainy.Core.Main.Verbal
 
 				// Translators: {0} is replaced by a question and {1} by the possible valid answers
 				// E.g.: What is the correct option? Answer A, B, C or D.
-				return String.Format (Translations.GetString ("{0} Answer {1}."),
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} Answer {1}."),
 					Current.question, Answer.GetMultiOptionsPossibleAnswers (Current.answers.Length));
 			}
 		}
@@ -65,7 +72,7 @@ namespace gbrainy.Core.Main.Verbal
 			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption;
 			Answer.SetMultiOptionAnswer (Current.right, Current.answers[Current.right]);
 
-			Container container = new Container (DrawAreaX, DrawAreaY + 0.2, 0.8, Current.answers.Length * 0.15);
+			Container container = new Container (DrawAreaX + 0.1, 0.50, 0.5, Current.answers.Length * 0.15);
 			AddWidget (container);
 	
 			for (int i = 0; i <  Current.answers.Length; i++)
@@ -82,7 +89,7 @@ namespace gbrainy.Core.Main.Verbal
 					int n = (int) e.Data;
 
 					e.Context.MoveTo (0.05, 0.02);
-					e.Context.ShowPangoText (String.Format (Translations.GetString ("{0}) {1}"), Answer.GetMultiOption (n), Current.answers[n].ToString ()));
+					e.Context.ShowPangoText (String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0}) {1}"), Answer.GetMultiOption (n), Current.answers[n].ToString ()));
 				};
 			}
 			SetAnswerCorrectShow ();
@@ -97,7 +104,7 @@ namespace gbrainy.Core.Main.Verbal
 
 			gr.SetPangoLargeFontSize ();
 			gr.MoveTo (0.1, DrawAreaY + 0.05);
-			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 		}
 	}
 }
