@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2011 Jordi Mas i Hernàndez <jmas@softcatala.org>
+ * Copyright (C) 2010 Jordi Mas i Hernàndez <jmas@softcatala.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -12,13 +12,17 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
 using System.Collections.Generic;
+using System.IO;
 using System.Text.RegularExpressions;
 
+using gbrainy.Core.Toolkit;
 using gbrainy.Core.Services;
 
 namespace gbrainy.Core.Main.Xml
@@ -43,19 +47,17 @@ namespace gbrainy.Core.Main.Xml
 		// Shared with all instances
 		static List <GameXmlDefinition> games;
 		static List <DefinitionLocator> locators;
+
+		static string option_prefix = "[option_prefix]";
 		static string option_answers = "[option_answers]";
 
 		DefinitionLocator current;
 		GameXmlDefinition game;
 		string question, answer, rationale, answer_show;
+		List <OptionDrawingObject> options;
 		ICSharpCompiler compiler;
-		GameXmlDrawing xml_drawing;
-
-		public GameXml ()
-		{
-			xml_drawing = new GameXmlDrawing (this);
-		}
 
+		
 		static public List <GameXmlDefinition> Definitions {
 			set {
 				games = value;
@@ -68,7 +70,7 @@ namespace gbrainy.Core.Main.Xml
 		}
 
 		public override string Name {
-			get { return Translations.GetString (game.Name); }
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString (game.Name); }
 		}
 
 		public override string Question {
@@ -82,17 +84,17 @@ namespace gbrainy.Core.Main.Xml
 		public override string Tip {
 			get {
 				if (game.Variants.Count > 0 && game.Variants[current.Variant].Tip != null)
-					return Translations.GetString (game.Variants[current.Variant].Tip);
+					return ServiceLocator.Instance.GetService <ITranslations> ().GetString (game.Variants[current.Variant].Tip);
 				else
 					if (String.IsNullOrEmpty (game.Tip) == false)
-						return Translations.GetString (game.Tip);
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString (game.Tip);
 					else
 						return null;
 			}
 		}
 
 		void SetAnswerCorrectShow ()
-		{
+		{		
 			if (String.IsNullOrEmpty (answer_show))
 				return;
 
@@ -113,10 +115,11 @@ namespace gbrainy.Core.Main.Xml
 
 			Answer.CheckExpression = expression;
 		}
-
+		
 		void SetCheckAttributes ()
 		{
 			GameAnswerCheckAttributes attrib;
+
 			if (game.Variants.Count > 0 && game.Variants[current.Variant].CheckAttributes != GameAnswerCheckAttributes.None)
 				attrib = game.Variants[current.Variant].CheckAttributes;
 			else
@@ -134,11 +137,6 @@ namespace gbrainy.Core.Main.Xml
 			bool variants;
 			LocalizableString localizable_question, localizable_rationale;
 
-			xml_drawing.CreateDrawingObjects (game.DrawingObjects); // Draw objects shared by all variants
-
-			if (game.Variants.Count > 0)
-				xml_drawing.CreateDrawingObjects (game.Variants[current.Variant].DrawingObjects); // Draw variant specific objects
-
 			compiler = ServiceLocator.Instance.GetService <ICSharpCompiler> ();
 
 			variants = game.Variants.Count > 0;
@@ -164,6 +162,7 @@ namespace gbrainy.Core.Main.Xml
 				compiler.EvaluateCode (variables);
 
 				try {
+
 					if (String.IsNullOrEmpty (localizable_question.Value) == false)
 						localizable_question.ValueComputed = Int32.Parse (ReplaceVariables (localizable_question.Value));
 
@@ -204,16 +203,22 @@ namespace gbrainy.Core.Main.Xml
 				answer_show = ReplaceVariables (answer_show);
 			}
 
-			int option_answer = xml_drawing.GetOptionCorrectAnswerIndex ();
-
-			if (option_answer != -1)
+			if (options != null && options.Count > 0)
 			{
-				Answer.SetMultiOptionAnswer (option_answer, answer);
+				for (int i = 0; i < options.Count; i++)
+				{
+					OptionDrawingObject option = options [i];
+					if (option.Correct == true)
+					{
+						Answer.SetMultiOptionAnswer (i, answer);
+						break;
+					}
+				}
 
 				// Translators {0}: list of options (A, B, C)
-				string answers = String.Format (Translations.GetString ("Answer {0}."),
-					Answer.GetMultiOptionsPossibleAnswers (xml_drawing.Options.Count));
-				question = question.Replace (option_answers, answers);
+				string answers = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Answer {0}."), 
+					Answer.GetMultiOptionsPossibleAnswers (options.Count));
+				question = question.Replace (option_answers, answers);					
 			}
 			else
 			{
@@ -224,6 +229,133 @@ namespace gbrainy.Core.Main.Xml
 			SetAnswerCorrectShow ();
 		}
 
+		void CreateDrawingObjects (GameXmlDefinitionVariant game)
+		{
+			OptionDrawingObject option;
+			double x = 0, y = 0, width = 0, height = 0;
+			bool first = true;
+			int randomized_options = 0;
+
+			if (game.DrawingObjects == null)
+				return;
+
+			// Calculate the size of container from the options and count the number of random options
+			foreach (DrawingObject draw_object in game.DrawingObjects)
+			{
+				option = draw_object as OptionDrawingObject;
+
+				if (option == null)
+					continue;
+
+				if (option.RandomizedOrder)
+					randomized_options++;
+
+				if (first == true)
+				{
+					x = option.X;
+					y = option.Y;
+					width = option.Width;
+					height = option.Height;
+					first = false;
+					continue;
+				}
+
+				if (option.X < x) 
+					x = option.X;
+
+				if (option.Y < y) 
+					y = option.Y;
+
+				if (option.X + option.Width > width)
+					width = option.X + option.Width;
+
+				if (option.Y + option.Height > height) 
+					height = option.Y + option.Height;
+			}
+
+			if (first == true)
+				return;
+
+			// Randomize the order of the options
+			if (randomized_options > 0)
+			{
+				OptionDrawingObject [] originals;
+				ArrayListIndicesRandom random_indices;
+				int index = 0;
+
+				random_indices = new ArrayListIndicesRandom (randomized_options);
+				originals = new OptionDrawingObject [randomized_options];
+				random_indices.Initialize ();
+
+				// Backup originals
+				for (int i = 0; i < game.DrawingObjects.Length; i++)
+				{
+					option = game.DrawingObjects[i] as OptionDrawingObject;
+
+					if (option == null)
+						continue;
+
+					originals[index] = option.Copy ();
+					index++;
+				}
+
+				// Swap
+				index = 0;
+				for (int i = 0; i < game.DrawingObjects.Length; i++)
+				{
+					option = game.DrawingObjects[i] as OptionDrawingObject;
+
+					if (option == null)
+						continue;
+
+					option.CopyRandomizedProperties (originals [random_indices [index]]);
+					index++;
+				}
+			}
+
+			Container container = new Container (x, y, width - x, height - y);
+			AddWidget (container);
+
+			if (options == null)
+				options = new List <OptionDrawingObject> ();
+
+			int idx = 0;
+
+			// Create drawing widgets objects
+			foreach (DrawingObject draw_object in game.DrawingObjects)
+			{
+				option = draw_object as OptionDrawingObject;
+
+				if (option == null)
+					continue;
+
+				DrawableArea drawable_area = new DrawableArea (option.Width, option.Height);
+				drawable_area.X = option.X;
+				drawable_area.Y = option.Y; // + i * 0.15;
+				container.AddChild (drawable_area);
+				
+				drawable_area.Data = idx;
+				drawable_area.DataEx = Answer.GetMultiOption (idx);
+				options.Add (option);
+
+				idx++;
+				drawable_area.DrawEventHandler += DrawOption;
+			}
+		}
+
+		void DrawOption (object sender, DrawEventArgs e)
+		{
+			int idx = (int) e.Data;
+
+			if (options.Count == 0)
+				return;
+
+			OptionDrawingObject _option = options [idx];
+			e.Context.SetPangoLargeFontSize ();
+
+			DrawObjects (e.Context, _option.DrawingObjects, idx);
+		}
+
 		public override int Variants {
 			get {
 				if (locators.Count == 0)
@@ -244,6 +376,12 @@ namespace gbrainy.Core.Main.Xml
 				current.Variant = locator.Variant;
 				game = games [locator.Game];
 				SetCheckAttributes ();
+
+				CreateDrawingObjects (game); // Draw objects shared by all variants
+
+				if (game.Variants.Count > 0)
+					CreateDrawingObjects (game.Variants[current.Variant]); // Draw variant specific objects
+
 				SetCheckExpression ();
 				SetAnswerCorrectShow ();
 			}
@@ -253,10 +391,87 @@ namespace gbrainy.Core.Main.Xml
 		{
 			base.Draw (gr, area_width, area_height, rtl);
 
-			xml_drawing.DrawObjects (gr, game.DrawingObjects, null); // Draw objects shared by all variants
+			DrawObjects (gr, game.DrawingObjects, null); // Draw objects shared by all variants
 
 			if (game.Variants.Count > 0)
-				xml_drawing.DrawObjects (gr, game.Variants[current.Variant].DrawingObjects, null); // Draw variant specific objects
+				DrawObjects (gr, game.Variants[current.Variant].DrawingObjects, null); // Draw variant specific objects
+		}
+
+		void DrawObjects (CairoContextEx gr, DrawingObject [] drawing_objects, int? option)
+		{
+			if (drawing_objects == null)
+				return;
+
+			foreach (DrawingObject draw_object in drawing_objects)
+			{
+				if (draw_object is OptionDrawingObject)
+					continue;
+
+				if (draw_object is TextDrawingObject)
+				{
+					string text;
+					TextDrawingObject draw_string = draw_object as TextDrawingObject;
+
+					text = CatalogGetString (draw_string.Text);
+					text = ReplaceVariables (text);
+
+					switch (draw_string.Size) {
+					case TextDrawingObject.Sizes.Small:
+						gr.SetPangoFontSize (0.018);
+						break;
+					case TextDrawingObject.Sizes.Medium:
+						gr.SetPangoNormalFontSize (); // 0.022
+						break;
+					case TextDrawingObject.Sizes.Large:
+						gr.SetPangoLargeFontSize (); // 0.0325
+						break;
+					case TextDrawingObject.Sizes.XLarge:
+						gr.SetPangoFontSize (0.06);
+						break;
+					case TextDrawingObject.Sizes.XXLarge:
+						gr.SetPangoFontSize (0.08);
+						break;
+					default:
+						throw new InvalidOperationException ("Invalid value");
+					}
+
+					if (draw_string.Centered) {
+						gr.DrawTextCentered (draw_string.X, draw_string.Y, text);
+					} else {
+						gr.MoveTo (draw_string.X, draw_string.Y);
+						if (option == null)
+							gr.ShowPangoText (text);
+						else
+							gr.ShowPangoText (GetOptionPrefix (text, (int) option));
+
+						gr.Stroke ();
+					}
+				}
+				else if (draw_object is ImageDrawingObject)
+				{
+					ImageDrawingObject image = draw_object as ImageDrawingObject;
+
+					if (String.IsNullOrEmpty (image.Filename) == false)
+					{
+						string dir;
+						IConfiguration config;
+
+						config = ServiceLocator.Instance.GetService <IConfiguration> ();
+						dir = config.Get <string> (ConfigurationKeys.GamesGraphics);
+
+						gr.DrawImageFromFile (Path.Combine (dir, image.Filename),
+							image.X, image.Y, image.Width, image.Height);
+					}
+				}
+			}
+		}
+
+		string GetOptionPrefix (string str, int option)
+		{
+			string answer;
+			
+			answer = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0}) "), Answer.GetMultiOption (option));
+			return str.Replace (option_prefix, answer);
 		}
 
 		static void BuildLocationList ()
@@ -272,16 +487,16 @@ namespace gbrainy.Core.Main.Xml
 		}
 
 		// Protect from calling with null (exception)
-		internal string CatalogGetString (string str)
+		static string CatalogGetString (string str)
 		{
 			if (String.IsNullOrEmpty (str))
 				return str;
 
-			return Translations.GetString (str);
+			return ServiceLocator.Instance.GetService <ITranslations> ().GetString (str);
 		}
 
 		// Protect from calling with null + resolve plurals
-		internal string CatalogGetString (LocalizableString localizable)
+		static string CatalogGetString (LocalizableString localizable)
 		{
 			if (localizable == null)
 				return string.Empty;
@@ -289,11 +504,11 @@ namespace gbrainy.Core.Main.Xml
 			if (localizable.IsPlural () == false)
 				return CatalogGetString (localizable.String);
 
-			return Translations.GetPluralString (localizable.String, localizable.PluralString, localizable.ValueComputed);
+			return ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (localizable.String, localizable.PluralString, localizable.ValueComputed);
 		}
 
 		// Replace compiler service variables
-		internal string ReplaceVariables (string str)
+		string ReplaceVariables (string str)
 		{
 			const string exp = "\\[[a-z_]+\\]+";
 			string var, var_value, all_vars;
