@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -418,9 +420,6 @@ namespace gbrainy.Core.Main.Xml
 						if (String.Compare (str, "yes", true) == 0)
 							option.Correct = true;
 
-						if (option.X + option.Width > 1 || option.Y + option.Height > 1)
-							Console.WriteLine ("GameXmlFactory. Wrong option size. x+width and y+height cannot be larger than 1");
-
 						break;
 					default:
 						if (String.IsNullOrEmpty (name) == false)
