@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 namespace gbrainy.Core.Services
@@ -20,7 +22,6 @@ namespace gbrainy.Core.Services
 	public interface ITranslations : IService
 	{
 		int TranslationPercentage { get;}
-		string Language { get; set; }
 
 		void Init (string package, string localedir);
 		string GetString (string s);
