@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using Cairo;
@@ -65,7 +67,7 @@ namespace gbrainy.Core.Toolkit
 
 				gr.Save ();
 
-				gr.SetSourceColor (new Cairo.Color (0.5, 0.5, 0.5, 1));
+				gr.Color = new Cairo.Color (0.5, 0.5, 0.5, 1);
 				gr.SetDash (dashes, 0);
 
 				if (SelectedArea.Width == 0 && SelectedArea.Height == 0)
@@ -96,7 +98,7 @@ namespace gbrainy.Core.Toolkit
 			} else {
 
 				if (args.EventType == MouseEventType.ButtonPress) {
-					OnSelected (new SelectedEventArgs (Data, DataEx));
+					OnSelected (new SeletectedEventArgs (Data, DataEx));
 				} else {
 					if (hoover == false) {
 						hoover = true;
