@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 
@@ -34,9 +36,8 @@ namespace gbrainy.Core.Views
 
 		public event EventHandler DrawRequest; // Not used in this view
 
-		public CountDownView (ITranslations translations, EventHandler OnFinish)
+		public CountDownView (EventHandler OnFinish)
 		{
-			Translations = translations;
 			timer = new System.Timers.Timer ();
 			timer.Elapsed += TimerUpdater;
 			timer.Interval = (1 * 1000); // 1 second
@@ -48,8 +49,6 @@ namespace gbrainy.Core.Views
 			get { return synchronize; }
 		}
 
-		private ITranslations Translations { get; set; }
-
 		public void Start ()
 		{
 			timer.SynchronizingObject = SynchronizingObject;
@@ -72,10 +71,10 @@ namespace gbrainy.Core.Views
 			gr.Scale (area_width, area_height);
 
 			gr.LineWidth = 0.01;
-			gr.SetSourceColor (new Cairo.Color (0, 0, 0, 1));
+			gr.Color = new Cairo.Color (0, 0, 0, 1);
 
 			gr.SetPangoLargeFontSize ();
-			gr.DrawTextCentered (0.5, 0.1, Translations.GetString ("Get ready to memorize the next objects..."));
+			gr.DrawTextCentered (0.5, 0.1, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Get ready to memorize the next objects..."));
 			gr.Stroke ();
 
 			gr.SetPangoFontSize (0.35);
