@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using gbrainy.Core.Main;
@@ -36,7 +38,7 @@ namespace gbrainy.Games.Calculation
 		private int max_operations;
 
 		public override string Name {
-			get {return Translations.GetString ("Arithmetical operations");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Arithmetical operations");}
 		}
 
 		public override GameTypes Type {
@@ -44,7 +46,7 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("What is the result of the following operation?");} 
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What is the result of the following operation?");} 
 		}
 
 		protected override void Initialize ()
@@ -62,7 +64,7 @@ namespace gbrainy.Games.Calculation
 				max_operand = 100;
 				break;
 			case GameDifficulty.Master:
-				max_operations = 4;
+				max_operations = 5;
 				max_operand = 500;
 				break;
 			}
@@ -110,7 +112,7 @@ namespace gbrainy.Games.Calculation
 			for (int i = 0; i < operands.Length - 1; i++)
 			{
 				gr.DrawTextAlignedRight (aligned_pos, operand_y, operands[i].ToString ());
-				gr.MoveTo (DrawAreaX + 0.3, operand_y + 0.03);
+				gr.MoveTo (DrawAreaX + 0.2, operand_y + 0.03);	
 
 				switch (operation) {
 				case Operation.Addition:
@@ -129,8 +131,8 @@ namespace gbrainy.Games.Calculation
 
 			gr.DrawTextAlignedRight (aligned_pos, operand_y, operands[operands.Length - 1].ToString ());
 
-			operand_y += 0.13;
-			gr.MoveTo (DrawAreaX + 0.3, operand_y);
+			operand_y += 0.08;
+			gr.MoveTo (DrawAreaX + 0.2, operand_y);
 			gr.LineTo (DrawAreaX + 0.5, operand_y);
 			gr.Stroke ();
 
