@@ -12,17 +12,22 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
 	public class PuzzleCountCircles : Game
 	{
+		private const double figure_size = 0.3;
+		private const double radian = Math.PI / 180;
 		private int n_circles;
 
 		class ItemCircle
@@ -40,15 +45,15 @@ namespace gbrainy.Games.Logic
 		ItemCircle[] circles;
 
 		public override string Name {
-			get {return Translations.GetString ("Count circles");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Count circles");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("How many circles do you count?");} 
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("How many circles do you count?");} 
 		}
 
 		public override string Tip {
-			get { return Translations.GetString ("It is an easy exercise if you systematically count the circles.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("It is an easy exercise if you systematically count the circles.");}
 		}
 
 		protected override void Initialize ()
