@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -29,26 +31,26 @@ namespace gbrainy.Games.Logic
 		enum QuestionType
 		{
 			TwoSquares	= 0,
-			TwoCircles,
-			ThreeCircles,
+			TwoCercles,
+			ThreeCercles,
 			Length		
 		}
 
 		public override string Name {
-			get {return Translations.GetString ("Figures and text");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Figures and text");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("The figures and the texts are related. What text should go under the last figure?");} 
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The figures and the text are related. What text should go under the last figure?");} 
 		}
 
 		public override string Tip {
-			get { return Translations.GetString ("Every character of the text represents a property of the figure.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Every character of the text represents a property of the figure.");}
 		}
 
 		public override string Rationale {
 			get {
-				return Translations.GetString ("'A' indicates that the figures overlap, 'B' that are squares, 'C' that are circles, 'D' that the figures are separated, 'E' that there are three figures and 'F' that there are two figures.");
+				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("'A' indicates that the figures overlap, 'B' that are squares, 'C' that are circles, 'D' that the figures are separated, 'E' that there are three figures and 'F' that there are two figures.");
 			}
 		}
 
@@ -61,11 +63,11 @@ namespace gbrainy.Games.Logic
 				Answer.Correct = "A | B | F";
 				Answer.CorrectShow = "ABF";
 				break;
-			case QuestionType.TwoCircles:
+			case QuestionType.TwoCercles:
 				Answer.Correct = "C | D | F";
 				Answer.CorrectShow = "CDF";
 				break;
-			case QuestionType.ThreeCircles:
+			case QuestionType.ThreeCercles:
 				Answer.Correct = "A | C | E";
 				Answer.CorrectShow = "ACE";
 				break;
@@ -131,14 +133,14 @@ namespace gbrainy.Games.Logic
 				gr.Stroke ();
 				gr.MoveTo (x + 0.05, y + 0.18);
 				break;
-			case QuestionType.TwoCircles:
+			case QuestionType.TwoCercles:
 				gr.Arc (x + 0.05, y + 0.05, 0.05, 0, 2 * Math.PI);
 				gr.Stroke ();
 				gr.Arc (x + 0.12 + 0.05, y + 0.05, 0.05, 0, 2 * Math.PI);
 				gr.Stroke ();
 				gr.MoveTo (x + 0.1, y + 0.18);
 				break;
-			case QuestionType.ThreeCircles:
+			case QuestionType.ThreeCercles:
 				gr.Arc (x + 0.05 + 0.06, y + 0.04, 0.05, 0, 2 * Math.PI);
 				gr.Stroke ();
 				gr.Arc (x + 0.05, y + 0.06 + 0.04, 0.05, 0, 2 * Math.PI);
