@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -29,6 +31,7 @@ namespace gbrainy.Games.Logic
 		const double figure_size = 0.25;
 		const int lines = 6;
 		const int columns = 6;
+		const int figures = 6;
 		static bool X = true;
 		static bool O = false;
 		const double space_figures = 0.05;
@@ -199,12 +202,12 @@ namespace gbrainy.Games.Logic
 		};
 
 		public override string Name {
-			get {return Translations.GetString ("Square with dots");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Square with dots");}
 		}
 
 		public override string Question {
 			get {return (String.Format (
-				Translations.GetString ("Which is the next logical figure in the sequence? Answer {0}, {1} or {2}."),
+				ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Which is the next logical figure in the sequence? Answer {0}, {1} or {2}."),
 				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2)));}
 		}
 
@@ -213,9 +216,9 @@ namespace gbrainy.Games.Logic
 			get {
 				switch (puzzle_index) {
 				case 0:
-					return Translations.GetString ("From the top-left figure, the top-left circle moves down, the bottom-left circle moves up, the bottom-right moves diagonally up-left and the top-right moves diagonally down-left.");
+					return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("From the top-left figure, the top-left circle moves down, the bottom-left circle moves up, the bottom-right moves diagonally up-left and the top-right moves diagonally down-left.");
 				case 2:
-					return Translations.GetString
+					return ServiceLocator.Instance.GetService <ITranslations> ().GetString
 					("From the top-left figure, the figure is rotated counterclockwise 90 degrees.");
 				case 1: // TODO
 				default:
@@ -334,7 +337,7 @@ namespace gbrainy.Games.Logic
 
 			y += figure_size + 0.10;
 			gr.MoveTo (x, y - 0.02);
-			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 		}
 	}
 }
