@@ -13,7 +13,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -39,19 +41,19 @@ namespace gbrainy.Games.Logic
 		private const int rows = 4, columns = 4;
 
 		public override string Name {
-			get {return Translations.GetString ("Numbers in a grid");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Numbers in a grid");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("The numbers in the grid below follow a pattern. Which number should replace the question mark?");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The numbers in the grid below follow a pattern. Which number should replace the question mark?");}
 		}
 
 		public override string Tip {
 			get { 
 				if (orientation) 
-					return Translations.GetString ("The pattern is arithmetical and works vertically.");
+					return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The pattern is arithmetical and works vertically.");
 				else 
-					return Translations.GetString ("The pattern is arithmetical and works horizontally.");
+					return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The pattern is arithmetical and works horizontally.");
 			}
 		}
 
@@ -60,21 +62,21 @@ namespace gbrainy.Games.Logic
 				switch (operation) {
 				case Operation.MultiplyAndAdd:
 					if (orientation) {
-						return Translations.GetString ("The fourth row is calculated by multiplying the first two rows and adding the third.");
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The fourth row is calculated by multiplying the first two rows and adding the third.");
 					} else {
-						return Translations.GetString ("The fourth column is calculated by multiplying the first two columns and adding the third.");
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The fourth column is calculated by multiplying the first two columns and adding the third.");
 					}
 				case Operation.MutilplyAndSubs:
 					if (orientation) {
-						return Translations.GetString ("The fourth row is calculated by multiplying the first two rows and subtracting the third.");
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The fourth row is calculated by multiplying the first two rows and subtracting the third.");
 					} else {
-						return Translations.GetString ("The fourth column is calculated by multiplying the first two columns and subtracting the third.");
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The fourth column is calculated by multiplying the first two columns and subtracting the third.");
 					}
 				case Operation.AddAndSubs:
 					if (orientation) {
-						return Translations.GetString ("The fourth row is calculated by adding the first two rows and subtracting the third.");
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The fourth row is calculated by adding the first two rows and subtracting the third.");
 					} else {
-						return Translations.GetString ("The fourth column is calculated by adding the first two columns and subtracting the third.");
+						return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The fourth column is calculated by adding the first two columns and subtracting the third.");
 					}
 				default:
 					return string.Empty;
