@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using Cairo;
@@ -26,7 +28,7 @@ namespace gbrainy.Games.Logic
 {
 	public class PuzzleLargerShape : Game
 	{
-		private const double rect_witdh = 0.04, rect_height = 0.04;
+		private const double rect_witdh = 0.04, rect_height = 0.04, space_figures = 0.22;
 		private ArrayListIndicesRandom random_indices;
 		private const int answers = 4;
 		private char[] quest1, quest2, answer;
@@ -108,7 +110,7 @@ namespace gbrainy.Games.Logic
 		};
 
 		public override string Name {
-			get {return Translations.GetString ("Larger shape");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Larger shape");}
 		}
 
 		public override bool UsesColors {
@@ -117,14 +119,14 @@ namespace gbrainy.Games.Logic
 
 		public override string Question {
 			get {return String.Format (
-				Translations.GetString ("Which larger shape can you make combining the first two figures? Answer {0}, {1}, {2} or {3}."),
+				ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Which larger shape can you make combining the first two figures? Answer {0}, {1}, {2} or {3}."),
 				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		protected override void Initialize ()
 		{
 			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
-			palette = new ColorPalette (Translations);
+			palette = new ColorPalette ();
 
 			switch (random.Next (2)) {
 			case 0:
@@ -298,7 +300,7 @@ namespace gbrainy.Games.Logic
 			base.Draw (gr, area_width, area_height, rtl);
 
 			gr.MoveTo (0.1, 0.3);
-			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 			gr.Stroke ();
 		}
 	}
