@@ -12,12 +12,15 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -29,16 +32,16 @@ namespace gbrainy.Games.Logic
 		private const int figures = 3;
 
 		public override string Name {
-			get {return Translations.GetString ("Squares and letters");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Squares and letters");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("The letters around the squares follow a pattern. Which letter should replace the question mark in the last square?");} 
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The letters around the squares follow a pattern. Which letter should replace the question mark in the last square?");} 
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Translations.GetString ("Every letter is calculated by taking the alphabetical position of the previous character and adding {0} to it in order to get the position of the next letter."), step);
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Every letter is calculated by taking the alphabetical position of the previous character and adding {0} to it in order to get the position of the next letter."), step);
 			}
 		}
 
