@@ -12,24 +12,26 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
 	public class PuzzleTimeNow : Game
 	{
-		const double figure_size = 0.5;
+		const double figure_size = 0.3;
 		int after;
 		DateTime position_a, position_b, ans, sample;
 
 		public override string Name {
-			// Translators: this the name of a game
-			get {return Translations.GetString ("Time now");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Time now");}
 		}
 
 		public override string Question {
@@ -39,7 +41,7 @@ namespace gbrainy.Games.Logic
 				// http://msdn.microsoft.com/en-us/library/system.globalization.datetimeformatinfo.aspx
 				// For 12-hour clock format use {0:%h} and for 24-hour clock format use {0:%H}. The date formats {0:h} and {0:H} are invalid.
 				//
-				Translations.GetPluralString (
+				ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (
 					"{0} hour ago it was as long after {1:h tt} as it was before {2:h tt} on the same day. What is the time now? Answer using the hour (e.g.: {3:h tt})",
 					"{0} hours ago it was as long after {1:h tt} as it was before {2:h tt} on the same day. What is the time now? Answer using the hour (e.g.: {3:h tt})",
 					after),
@@ -48,7 +50,7 @@ namespace gbrainy.Games.Logic
 
 		public override string Rationale {
 			get {
-				return String.Format (Translations.GetPluralString (
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString (
 					"Determine the hour half way between the given times, and then add {0} hour to convert it to the present time.",
 					"Determine the hour half way between the given times, and then add {0} hours to convert it to the present time.",
 					after),
@@ -80,18 +82,17 @@ namespace gbrainy.Games.Logic
  			// Explanation of the date and time format specifications can be found here:
 			// http://msdn.microsoft.com/en-us/library/system.globalization.datetimeformatinfo.aspx
 			// For 12-hour clock format use {0:%h} and for 24-hour clock format use {0:%H}. The date formats {0:h} and {0:H} are invalid.
-			// 'tt' is the A.M./P.M. designator 
-			Answer.Correct = String.Format (Translations.GetString ("{0:h tt}"), ans);
+			Answer.Correct = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0:h tt}"), ans);
 			Answer.CheckAttributes = GameAnswerCheckAttributes.IgnoreCase | GameAnswerCheckAttributes.IgnoreSpaces;
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
 		{
 			base.Draw (gr, area_width, area_height, rtl);
+			gr.DrawClock (DrawAreaX + 0.4, DrawAreaY + 0.4, figure_size,
+				0, 0 /* No hands */);
 
-			gr.DrawClock (DrawAreaX + 0.15, DrawAreaY + 0.1, figure_size,0, 0 /* No hands */);
-			gr.SetPangoLargeFontSize ();
-			gr.DrawTextCentered (0.5, DrawAreaY + 0.2 + figure_size, Translations.GetString ("Sample clock"));
+			gr.DrawTextCentered (0.5, DrawAreaY + 0.3 + figure_size, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Sample clock"));
 		}
 	}
 }
