@@ -12,13 +12,16 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
+
 using System;
 
 using gbrainy.Core.Main;
-
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -26,20 +29,20 @@ namespace gbrainy.Games.Logic
 	{
 		int type;
 		public override string Name {
-			get {return Translations.GetString ("Triangles");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Triangles");}
 		}
 
 		public override string Question {
-			get {return Translations.GetString ("How many triangles of any size do you count in the figure below?");} 
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("How many triangles of any size do you count in the figure below?");} 
 		}
 
 		public override string Tip {
-			get { return Translations.GetString ("A triangle can be embedded inside another triangle.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("A triangle can be embedded inside another triangle.");}
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Translations.GetString ("The triangles are made by connecting the following points: {0}"),
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The triangles are made by connecting the following points: {0}"),
 					(type == 0) ? "bdc, dcf, dfg, abd, ade, edg, acg, abg, bcg, afg, ecg, acd, acf, ace, adg, cdg." : 
 					"dcf, ade, acg, afg, ecg, acd, acf, ace.");
 			}
