@@ -12,7 +12,9 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 using System;
@@ -32,7 +34,6 @@ namespace gbrainy.Test.Clients.Classical
 
 		public class TranslationsTest : ITranslations
 		{
-			public string Language { set; get; }
 			public int Percentage { set; get; }
 			public int TranslationPercentage {
 				get { return Percentage; }
@@ -46,43 +47,45 @@ namespace gbrainy.Test.Clients.Classical
 		[TestFixtureSetUp]
 		public void Construct ()
 		{
+			RegisterDefaultServices ();
 			translations =  new TranslationsTest ();
+			ServiceLocator.Instance.RegisterService (typeof (ITranslations), translations);
 		}
 
 		[Test]
 		public void ShowTranslationMessageHonorPercentage ()
 		{
-			GtkClient client = new GtkClient (translations);
+			GtkClient client = new GtkClient ();
 			Preferences.ConfigPath = ".";
 			Preferences.Clear ();
 
 			translations.Percentage = client.MIN_TRANSLATION;
-			Assert.AreEqual (false, client.ShouldShowTranslationWarning ());
+			Assert.AreEqual (false, client.ShowTranslationWarning ());
 		}
 
 		[Test]
 		public void ShowTranslationMessageOnlyOnce ()
 		{
-			GtkClient client = new GtkClient (translations);
+			GtkClient client = new GtkClient ();
 			Preferences.ConfigPath = ".";
 			Preferences.Clear ();
 
 			translations.Percentage = client.MIN_TRANSLATION - 1;
-			Assert.AreEqual (true, client.ShouldShowTranslationWarning ());
-			Assert.AreEqual (false, client.ShouldShowTranslationWarning ());
+			Assert.AreEqual (true, client.ShowTranslationWarning ());
+			Assert.AreEqual (false, client.ShowTranslationWarning ());
 		}
 
 		[Test]
 		public void ShowTranslationMessageWhenChangingVersion ()
 		{
-			GtkClient client = new GtkClient (translations);
+			GtkClient client = new GtkClient ();
 			Preferences.ConfigPath = ".";
 			Preferences.Clear ();
 
 			translations.Percentage = client.MIN_TRANSLATION - 1;
-			Assert.AreEqual (true, client.ShouldShowTranslationWarning ());
+			Assert.AreEqual (true, client.ShowTranslationWarning ());
 			Preferences.Set <string> (Preferences.EnglishVersionKey, "n.n.n");
-			Assert.AreEqual (true, client.ShouldShowTranslationWarning ());
+			Assert.AreEqual (true, client.ShowTranslationWarning ());
 		}
 	}
 }
